# -*- coding: utf-8 -*-

from django.test import TestCase
from portailuser.models import Ecole, PortailUser
from datetime import datetime, timedelta
from formations.models import Formation, Inscription, prochaine_formation


class TestFormation(TestCase):
    "Test de l'objet Formation"

    def setUp(self):
        self.user = PortailUser.objects.create(ecole=Ecole.inp, username="tatat", first_name="Toto", last_name="Tata")
        self.user1 = PortailUser.objects.create(ecole=Ecole.inp, username="1bidule", first_name="1", last_name="Bidule")
        self.user2 = PortailUser.objects.create(ecole=Ecole.inp, username="2bidule", first_name="2", last_name="Bidule")
        self.formation = Formation.objects.create(
            nom="Pipotron",
            description="Coucou, tu veux voir ma description ?",
            date_heure=datetime(2015, 2, 20, 16, 20, 52, 371798),
            duree=30,
            responsable=self.user,
            nb_fixes=2,
            nb_portables=3,
            lieu="DTC",
            ecole=Ecole.inp,
        )
        self.inscr = Inscription.objects.create(formation=self.formation, inscrit=self.user, a_portable=False)

    def test_est_inscrit_ko(self):
        self.assertFalse(self.formation.est_inscrit(self.user1))

    def test_est_inscrit_ok(self):
        self.assertTrue(self.formation.est_inscrit(self.user))

    def test_places_fixes(self):
        self.assertEqual(self.formation.places_fixes(), 1)

    def test_places_portables(self):
        self.assertEqual(self.formation.places_portables(), 3)

    def test_est_complete(self):
        self.assertFalse(self.formation.est_complete())

    def test_inscrit_deja(self):
        self.assertIsNone(self.formation.inscrire(self.user, False))

    def test_inscriptions(self):
        self.assertEqual(self.formation.inscriptions(), "Toto Tata")

    def test_desinscrit(self):
        self.formation.desinscrire(self.user)
        self.assertEqual(self.formation.inscriptions(), "")


class TestProchaineFormation(TestCase):
    def setUp(self):
        self.user = PortailUser.objects.create(ecole=Ecole.inp, username="tatat", first_name="Toto", last_name="Tata")
        self.formation = Formation.objects.create(
            nom="Pipotron",
            description="Coucou, tu veux voir ma description ?",
            date_heure=datetime.today() + timedelta(days=1),
            duree=30,
            responsable=self.user,
            nb_fixes=2,
            nb_portables=3,
            lieu="DTC",
            ecole=Ecole.inp,
        )
        self.inscr = Inscription.objects.create(formation=self.formation, inscrit=self.user, a_portable=False)

    def test_prochaine_formation(self):
        self.assertEqual(prochaine_formation(self.user), self.inscr.formation)

    def test_prochaine_formation_none(self):
        self.formation.date_heure = datetime.today() + timedelta(days=8)
        self.formation.save()
        self.assertIsNone(prochaine_formation(self.user))
